CLOSURE: complete listing of original samples of underlying raw evidence
Crate closure-core implements the CLOSURE technique for efficiently reconstructing all possible distributions of raw data from summary statistics. It is not about the Rust feature called closure.
The crate is mostly meant to serve as a backend for the R package unsum.
The only API users are likely to need is dfs_parallel().
Most of the code was written by Claude 3.5, translating Python code by Nathanael Larigaldie.
Functions
- count_
initial_ combinations - Count first set of integers
- dfs_
parallel - Generate all valid combinations