dfs_parallel

Function dfs_parallel 

pub fn dfs_parallel<T, U>(
    mean: T,
    sd: T,
    n: U,
    scale_min: U,
    scale_max: U,
    rounding_error_mean: T,
    rounding_error_sd: T,
) -> Vec<Vec<U>>
Generate all valid combinations

dfs_parallel() computes all valid combinations of integers that match the given summary statistics.

Arguments

  • mean - The mean of the target distribution.
  • sd - The standard deviation of the target distribution.
  • n - The number of elements in the target distribution.
  • scale_min - The minimum value of the scale.
  • scale_max - The maximum value of the scale.
  • rounding_error_mean - The rounding error for the mean.
  • rounding_error_sd - The rounding error for the standard deviation.

Returns

A vector of vectors, where each inner vector represents a valid combination of integers that matches the given summary statistics.