CLOSURE: complete listing of original samples of underlying raw evidence
Crate closure-core implements the CLOSURE technique for efficiently reconstructing all possible distributions of raw data from summary statistics. It is not about the Rust feature called closure.
The only API users are likely to need is dfs_parallel(). This function applies
the lower-level dfs_branch() in parallel and writes results to disk (currently
into a CSV file, but this may change in the future.)
Most of the code was written by Claude 3.5, translating Python code by Nathanael Larigaldie.
Functions
- dfs_
branch - Collect all valid combinations from a starting point
- dfs_
parallel - Run CLOSURE across starting combinations and write results to disk